@@ -20,11 +20,15 @@
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
  * @copyright  2003-2009 PgPool Global Development Group
- * @version    CVS: $Id: command.php,v 1.8 2009/01/25 08:16:30 t-ishii Exp $
+ * @version    CVS: $Id: command.php,v 1.12 2011/10/12 07:38:33 anzai Exp $
  */
 
 require_once('common.php');
 
+// timeout seconds
+// (The parameter "pcp_timeout" existed till V3.0.)
+define('PCP_TIMEOUT', 10);
+
 /**
  * Execute pcp command
  *
@@ -32,29 +36,35 @@ require_once('common.php');
  * @param srgs $num
  * @return array
  */
-function execPcp($command, $num='') {
+function execPcp($command, $num = '')
+{
     $pcpStatus = array (
-        '0' => 'SUCCESS',
-        '1' => 'UNKNOWNERR',
-        '2' => 'EOFERR',
-        '3' => 'NOMEMERR',
-        '4' => 'READERR',
-        '5' => 'WRITEERR',
-        '6' => 'TIMEOUTERR',
-        '7' => 'INVALERR',
-        '8' => 'CONNERR',
-        '9' => 'NOCONNERR',
-        '10' => 'SOCKERR',
-        '11' => 'HOSTERR',
-        '12' => 'BACKENDERR',
-        '13' => 'AUTHERR',
+        '0'   => 'SUCCESS',
+        '1'   => 'UNKNOWNERR',
+        '2'   => 'EOFERR',
+        '3'   => 'NOMEMERR',
+        '4'   => 'READERR',
+        '5'   => 'WRITEERR',
+        '6'   => 'TIMEOUTERR',
+        '7'   => 'INVALERR',
+        '8'   => 'CONNERR',
+        '9'   => 'NOCONNERR',
+        '10'  => 'SOCKERR',
+        '11'  => 'HOSTERR',
+        '12'  => 'BACKENDERR',
+        '13'  => 'AUTHERR',
         '127' => 'COMMANDERROR'
     );
 
     $param = readPcpInfo();
     $param['hostname'] = _PGPOOL2_PCP_HOSTNAME;
 
-    $args = " " . $param['pcp_timeout'] . " " . $param['hostname'] . " " . $param['pcp_port'] . " ". $_SESSION[SESSION_LOGIN_USER] . " " . $_SESSION[SESSION_LOGIN_USER_PASSWORD] . " " . $num;
+    $args = " " . PCP_TIMEOUT.
+            " " . $param['hostname'] .
+            " " . $param['pcp_port'] .
+            " ". $_SESSION[SESSION_LOGIN_USER] .
+            " '" . $_SESSION[SESSION_LOGIN_USER_PASSWORD] . "' " .
+            $num;
 
     switch ($command) {
         case 'PCP_NODE_COUNT':
@@ -66,47 +76,47 @@ function execPcp($command, $num='') {
             $cmd = _PGPOOL2_PCP_DIR . '/pcp_node_info' . $args;
             $ret = exec($cmd, $output, $return_var);
             break;
-            
+
         case 'PCP_ATTACH_NODE':
             $cmd = _PGPOOL2_PCP_DIR . '/pcp_attach_node' . $args;
             $ret = exec($cmd, $output, $return_var);
             break;
-            
+
         case 'PCP_DETACH_NODE':
             $cmd = _PGPOOL2_PCP_DIR . '/pcp_detach_node' . $args;
             $ret = exec($cmd, $output, $return_var);
             break;
-            
+
         case 'PCP_PROC_COUNT':
             $cmd = _PGPOOL2_PCP_DIR . '/pcp_proc_count' . $args;
             $ret = exec($cmd, $output, $return_var);
             break;
-            
+
         case 'PCP_PROC_INFO':
             $cmd = _PGPOOL2_PCP_DIR . '/pcp_proc_info' . $args;
             $ret = exec($cmd, $output, $return_var);
             $ret = $output;
             break;
-            
-        case 'PCP_START_PGPOOL':
-			$configOption = ' -f ' . _PGPOOL2_CONFIG_FILE . ' -F ' . _PGPOOL2_PASSWORD_FILE;
-			
-			if(isPipe($num)) {
-				$cmdOption = $configOption . $num . ' > /dev/null &';
-			} else {
-				$cmdOption = $configOption . $num . ' 2>&1 &';
-			}
 
-			/* we should not check pid file here.
-			 * let pgpool handle bogus pid file
+        case 'PCP_START_PGPOOL':
+            $configOption = ' -f ' . _PGPOOL2_CONFIG_FILE .
+                            ' -F ' . _PGPOOL2_PASSWORD_FILE;
+
+            if(isPipe($num)) {
+                $cmdOption = $configOption . $num . ' > /dev/null &';
+            } else {
+                $cmdOption = $configOption . $num . ' 2>&1 &';
+            }
+
+            /* we should not check pid file here.
+             * let pgpool handle bogus pid file
              * if(DoesPgpoolPidExist()) {
              *   return array('FAIL'=> '');
              * }
-			 */
+             */
             $cmd = _PGPOOL2_COMMAND . $cmdOption;
-			//var_dump($cmd);exit;
             $ret = exec($cmd, $output, $return_var);
-            if($return_var == 0) {
+            if ($return_var == 0) {
                 return array($pcpStatus[$return_var] => $output);
             } else {
                 return array('FAIL' => $output);
@@ -115,23 +125,30 @@ function execPcp($command, $num='') {
 
         case 'PCP_RELOAD_PGPOOL':
             $cmdOption = $num;
-            $cmdOption = $cmdOption . ' -f ' . _PGPOOL2_CONFIG_FILE
-                                                    . ' -F ' . _PGPOOL2_PASSWORD_FILE . ' reload';
+            $cmdOption = $cmdOption .
+                         ' -f ' . _PGPOOL2_CONFIG_FILE .
+                         ' -F ' . _PGPOOL2_PASSWORD_FILE . ' reload';
             $cmd = _PGPOOL2_COMMAND . $cmdOption . ' 2>&1 &';
             $ret = exec($cmd, $output, $return_var);
-            if($return_var == 0) {
+            if ($return_var == 0) {
                 return array($pcpStatus[$return_var] => $output);
             } else {
                 return array('FAIL' => $output);
             }
             break;
 
-
         case 'PCP_STOP_PGPOOL':
             $cmd = _PGPOOL2_PCP_DIR . '/pcp_stop_pgpool' . $args;
             $ret = exec($cmd, $output, $return_var);
             break;
 
+        case 'PCP_PROMOTE_NODE':
+            // -g option means that standby doesn't become primary
+            // untill all connection get closed.
+            $cmd = _PGPOOL2_PCP_DIR . '/pcp_promote_node' .' -g '. $args;
+            $ret = exec($cmd, $output, $return_var);
+            break;
+
         case 'PCP_RECOVERY_NODE':
             $cmd = _PGPOOL2_PCP_DIR . '/pcp_recovery_node' . $args;
             $ret = exec($cmd, $output, $return_var);
@@ -148,9 +165,9 @@ function execPcp($command, $num='') {
  *
  * @return array
  */
-function readPcpInfo() {
-    
-    $params = readConfigParams(array('pcp_port', 'pcp_timeout'));
+function readPcpInfo()
+{
+    $params = readConfigParams(array('pcp_port'));
     return $params;
 }
 ?>
