@@ -20,12 +20,15 @@
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
  * @copyright  2003-2008 PgPool Global Development Group
- * @version    CVS: $Id: ja.lang.php,v 1.21 2010/08/16 10:06:42 t-ishii Exp $
+ * @version    CVS: $Id: ja.lang.php,v 1.23 2011/10/12 07:42:08 anzai Exp $
  */
 
 $message = array(
     'lang' => 'ja',
     'strLang' => '日本語',
+
+    'descAuthentication_timeout' => 'クライアント認証のタイムアウト時間(秒)',
+    'descBackend_flag' => 'フェイルオーバやデタッチの可否',
     'descBackend_hostname' => 'pgpoolが接続するPostgreSQLサーバ(postmaster)が動いているホスト名',
     'descBackend_port' => 'PostgreSQLサーバのポート番号',
     'descBackend_socket_dir' => 'PostgreSQLサーバのUnix domain socketのディレクトリ',
@@ -34,17 +37,19 @@ $message = array(
     'descBlack_function_list' => 'データベースに書き込みを行なうカンマ区切りの関数のリスト',
     'descChild_life_time' => 'pgpoolの子プロセスの寿命',
     'descChild_max_connections' => '各pgpool子プロセスが終了するまでの接続回数',
-	'descClient_idle_limit' => 'クライアントからのクエリの最大待ち時間(秒)',
-	'descAuthentication_timeout' => 'クライアント認証のタイムアウト時間(秒)',
+    'descClient_idle_limit' => 'クライアントからのクエリの最大待ち時間(秒)',
+    'descClient_idle_limit_in_recovery' => 'リカバリ中のクライアントからのクエリの最大待ち時間(秒)',
     'descConnection_cache' => 'コネクションキャッシュ機能の有無',
     'descConnection_life_time' => 'コネクションプール中のコネクションの有効期間(秒)',
+    'descDebug_level' => 'デバッグメッセージの詳細レベル（0は無効）',
     'descDelay_threshold' => '許容するスタンバイサーバの遅延(バイト)',
-	'descEnable_pool_hba' => 'クライアント認証機能の有無',
+    'descEnable_pool_hba' => 'クライアント認証機能の有無',
     'descEnable_query_cache' => 'クエリキャッシュ機能の有無',
     'descFailover_command' => 'ノード切り離し時に起動するコマンド',
     'descFailback_command' => 'ノード復帰時に起動するコマンド',
     'descFailover_if_affected_tuples_mismatch' => '更新行数が一致しないときにフェイルオーバ',
     'descFail_over_on_backend_error' => 'DBノードへのソケット通信エラー時にフェイルオーバ',
+    'descFollow_master_command' => 'マスタのフェイルオーバ後に実行するコマンド',
     'descHealth_check_period' => 'ヘルスチェックを行う間隔(秒)',
     'descHealth_check_timeout' => 'ヘルスチェックが長時間待たされるのを防ぐためのタイムアウト値(秒)',
     'descHealth_check_user' => 'ヘルスチェックを行うためのPostgreSQLユーザ名',
@@ -53,8 +58,9 @@ $message = array(
     'descListen_addresses' => 'TCP/IPコネクションを受け付けるアドレス',
     'descLoad_balance_mode' => 'レプリケーションモード時にSELECT文を各ノードにロードバランス',
     'descLobj_lock_table' => 'ラージオブジェクトのレプリケーションでロック管理に使うためのテーブル名',
-	'descLog_connections' => '受信した接続のログを出力',
-	'descLog_hostname' => 'クライアントのホスト名を"ps"ステータスに出力',
+    'descLog_connections' => '受信した接続のログを出力',
+    'descLog_destination' => 'ログの出力先',
+    'descLog_hostname' => 'クライアントのホスト名を"ps"ステータスに出力',
     'descLog_standby_delay' => 'スタンバイサーバの遅延をログに記録する',
     'descLog_statement' => 'SQL文をログ出力',
     'descLogdir' => 'pgpoolの各種ログファイルを格納するディレクトリ',
@@ -76,18 +82,24 @@ $message = array(
     'descRecovery_1st_stage_command' => 'オンラインリカバリ第1ステージで実行するコマンド',
     'descRecovery_2nd_stage_command' => 'オンラインリカバリ第2ステージで実行するコマンド',
     'descRecovery_timeout' => 'オンラインリカバリ終了までの待ち時間(秒)。0 は待ち時間無し',
-	'descClient_idle_limit_in_recovery' => 'リカバリ中のクライアントからのクエリの最大待ち時間(秒)',
+    'descRelcache_expire' => 'システムカタログキャッシュの有効時間(秒)',
     'descReplication_mode' => 'レプリケーションモードの有効化',
     'descReplication_stop_on_mismatch' => 'マスタ/セカンダリ間のデータ不一致時に縮退運転',
-	'descReplicate_select' => 'SELECT 文のレプリケーション',
-    'descReplication_timeout' => 'デッドロックを監視するためのタイムアウト時間',
+    'descReplicate_select' => 'SELECT 文のレプリケーション',
+    'descReplication_timeout' => 'デッドロックを監視するためのタイムアウト時間。'.
+                                 '厳密でないレプリケーションモードでは、デッドロックが発生しやすくなります。',
     'descReset_query_list' => 'セッションが終了するときにコネクションを初期化するためのSQLコマンド',
+    'descSocket_dir' => 'pgpoolがコネクションを受け付けるUnix domain socketディレクトリ',
     'descSsl' => 'pgpool-IIとバックエンドの間のSSL接続',
     'descSsl_ca_cert' => 'opensslの-CAFileに指定するパス',
     'descSsl_ca_cert_dir' => 'opensslの-CApathに指定するディレクトリパス',
     'descSsl_cert' => 'フロントエンドとの接続に使用する公開x509証明書のフルパス',
     'descSsl_key' => 'フロントエンドとの接続に使用するプライベートキーファイルのフルパス',
-    'descSocket_dir' => 'pgpoolがコネクションを受け付けるUnix domain socketディレクトリ',
+    'descSr_check_period' => 'ストリーミングレプリケーションの遅延チェックの間隔(秒)',
+    'descSr_check_user' => 'ストリーミングレプリケーションの遅延チェックを行うユーザ',
+    'descSr_check_password' => 'ストリーミングレプリケーションの遅延チェックを行うユーザのパスワード',
+    'descSyslog_facility' => 'Syslogのファシリティ',
+    'descSyslog_ident' => 'Syslog中でのプログラム名',
     'descSystem_db_dbname' => 'System DBのデータベース名',
     'descSystem_db_hostname' => 'System DBが動いているホスト名',
     'descSystem_db_password' => 'System DBに接続するユーザのパスワード',
@@ -95,25 +107,28 @@ $message = array(
     'descSystem_db_schema' => 'System DBのスキーマ',
     'descSystem_db_user' => 'System DBに接続するときのユーザ名',
     'descWhite_function_list' => 'データベースに書き込みを行なわないカンマ区切りの関数のリスト',
+
     'errAlreadyExist' => 'すでに登録されています',
     'errFileNotExecutable' => 'コマンドを実行できません',
     'errFileNotFound' => 'ファイルが見つかりません',
     'errFileNotWritable' => 'ファイルの書き込みができません',
     'errIllegalHostname' => '不正なホスト名です',
-	'errIllegalPipe' => 'パイプの指定が不正です',
+    'errIllegalPipe' => 'パイプの指定が不正です',
     'errInputEverything' => 'すべてを入力してください',
     'errNoDefined' => 'パラメータが設定されていません',
-    'errNotSameLength' => '列名リストと列データ型リストの配列の長さが一致しません。同じ要素数である必要があります。',
+    'errNotSameLength' => '列名リストと列データ型リストの配列の長さが一致しません。'.
+                          '同じ要素数である必要があります。',
     'errPasswordMismatch' => 'パスワードが一致しません',
     'errRequired' => 'これは必須項目です',
     'errShouldBeInteger' => '0以上の整数を入力してください',
     'errShouldBeZeroOrMore' => '0以上である必要があります',
     'errSingleQuotation' => '配列要素をシングルクォーテーションで囲んでください。',
+
     'msgDeleteConfirm' => '本当に削除してよいですか？',
     'msgMasterDbConnectionError' => 'マスターDBに接続できません',
     'msgPgpoolConfNotFound' => 'pgpool.confが見つかりません',
     'msgPleaseSetup' => '設定ファイルが見つかりません。セットアップを実行してください。',
-	'msgReloadPgpool' => '設定ファイルを再読み込みしてもよろしいですか？',
+    'msgReloadPgpool' => '設定ファイルを再読み込みしてもよろしいですか？',
     'msgRestart' => '変更を反映するには再起動してください',
     'msgRestartPgpool' => 'pgpoolを再起動してよろしいですか？',
     'msgSameAsPasswordFile' => '値はパスワードファイルの設定値となります',
@@ -124,6 +139,8 @@ $message = array(
     'msgDetachConfirm' => 'このノードを切断してよいですか？',
     'msgReturnConfirm' => 'このノードを復帰させてよいですか？',
     'msgRecoveryConfirm' => 'このノードをリカバリしますか？',
+    'msgRPromoteConfirm' => 'このノードをマスタに昇格しますか？',
+
     'strAdd' => '追加',
     'strAdminPassword' => '管理者パスワード',
     'strBack' => '戻る',
@@ -207,7 +224,7 @@ $message = array(
     'strPgpoolLogFile' => 'pgpoolログ出力先',
     'strPgpoolManagementSystem' => 'pgpool-II管理システム',
     'strPgpoolServer' => 'pgpool-IIサーバ',
-    'strPgpoolStatus' => 'pgpoolステータス',    
+    'strPgpoolStatus' => 'pgpoolステータス',
     'strPgpoolSummary' => 'サマリー',
     'strPleaseWait' => 'しばらくお待ちください・・・',
     'strPort' => 'ポート',
@@ -215,6 +232,7 @@ $message = array(
     'strProcId' => 'プロセスID',
     'strProcInfo' => 'プロセス情報',
     'strProcTime' => 'プロセススタート時刻',
+    'strPromote' => 'マスタ昇格',
     'strProtocolMajorVersion' => 'プロトコルメジャーバージョン',
     'strProtocolNinorVersion' => 'プロトコルマイナーバージョン',
     'strQueryCache' => 'クエリキャッシュ',
@@ -248,6 +266,7 @@ $message = array(
     'strUpdate' => '更新',
     'strValue' => '値',
     'strWeight' => 'ウェイト',
+
     'e1' => 'pgmgt.conf.phpが見つかりません',
     'e2' => 'メッセージカタログが見つかりません',
     'e3' => 'pcpコマンドエラーが発生しました',
@@ -292,7 +311,8 @@ $message = array(
     'e6003' => 'pcp.confに書き込みができません',
     'e7001' => 'pcp.confが見つかりません',
     'e8001' => '詳細情報が取得できません',
-    'cautionaryNote' => '注: 更新した設定を反映させるには、設定のリロードが必要です。また、[*]が付いている項目は pgpool の再起動が必要となります。',
+    'cautionaryNote' => '注: 更新した設定を反映させるには、設定のリロードが必要です。'.
+                        'また、[*]が付いている項目は pgpool の再起動が必要となります。',
 
 );
 
